/* *****************************************************************************
  This file is part of the kde-game 'kjumpingCube'

  Copyright (C) 1998 by Matthias Kiefer <Matthias.Kiefer@stud.uni-karlsruhe.de>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  *******************************************************************************/  

#ifndef  ENGINE_H
#define ENGINE_H

class CubeSimBox;

/**
* Class Engine computes a (good) possibility to move
* for a given playingfield.
*
* At the moment it's not a clever algorithm, it just checks every move up to
* a maximum depth.
* 
* @short The games brain
*/
class Engine
{
   public:
      /**
      * @param initValue used for init the generation of chance numbers.
      * If no value is given it uses time().
      * @see Engine::init    
      */
      Engine(int initValue=0);
      /**
      * init the generation of chance numbers
      */
      void init(int);
      /**
      * sets skill of the Engine: 1 is easiest
      * @return old skill
      */
      int setSkill(int newSkill);
      /**
      *@return current skill
      */
      int getSkill();
      /**
      * Computes a (good) possible move at the given field.
      * The index of this Cube is stored in given 'row' and 'column' 
      * 
      * @return FALSE if computing was stopped
      * @see Engine#stop;  
      */
      bool getHint(int& row, int& column, int player, CubeSimBox);
      /**
      * stops the Engine
      */
      void stop();
      /**
      * @return TRUE if Engine is thinking at the moment
      */
      bool isActive();
            
   private:
      int doMove(int row,int column,int player, CubeSimBox);
      int currentLevel;
      int currentPlayer;
      int maxLevel;      
      bool stopped;
      bool active;
      int skill;
      
};


#endif // ENGINE_H
